@@ -8,8 +8,8 @@
 
    For documentation, see drvplot.cpp.
 
-   Written by Robert S. Maier <rsm@math.arizona.edu> and Wolfgang Glunz
-   <wglunz@pstoedit.net>.
+   Written by Robert S. Maier <rsm_AT_math.arizona.edu> and Wolfgang Glunz
+   <wglunz34_AT_pstoedit.net>.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -34,26 +34,36 @@ class drvplot : public drvbase
  public:
   derivedConstructor (drvplot);	// ctor
   ~drvplot();			// dtor
+	class DriverOptions : public ProgramOptions {
+	public:
+		Option < RSString, RSStringValueExtractor> type;
+		DriverOptions():
+			type(true,"plotformat","string",0,"plotutil format to generate",0,(const char *)"meta")
+	// pagesize(true,"-pagesize","string",0,"page size, e.g. a4",0,)
+		{
+			ADD(type);
+		}
+
+	}*options;
   
 #include "drvfuncs.h"
-  virtual void show_image (const PSImage& imageinfo); 
-  void show_text(const TextInfo & textInfo);
-  void show_rectangle(const float llx, const float lly, const float urx, const float ury);
 
+	virtual void show_image (const PSImage& imageinfo); 
+	void show_text(const TextInfo & textInfo);
+	void show_rectangle(const float llx, const float lly, const float urx, const float ury);
   
 private:
 	void print_coords();
-  class Plotter *plotter;	// either declared in plotter.h, or faked
-  bool physical_page;		// can map PS onto a page of specified size?
-  int page_type;		// if so, one of PAGE_{ANSI_A,ISO_A4...}
+	class Plotter *plotter;	// either declared in plotter.h, or faked
+	bool physical_page;		// can map PS onto a page of specified size?
+	int page_type;		// if so, one of PAGE_{ANSI_A,ISO_A4...}
 
-  void set_line_style (void);
-  void set_filling_and_edging_style (void);
+	void set_line_style (void);
+	void set_filling_and_edging_style (void);
    
-  NOCOPYANDASSIGN(drvplot)
+	NOCOPYANDASSIGN(drvplot)
 };
 
 #endif
  
  
- 
