@@ -2,7 +2,7 @@
    drvSAMPL.cpp : This file is part of pstoedit
    Skeleton for the implementation of new backends
 
-   Copyright (C) 1993 - 2006 Wolfgang Glunz, wglunz34_AT_pstoedit.net
+   Copyright (C) 1993 - 2007 Wolfgang Glunz, wglunz34_AT_pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -172,7 +172,7 @@ void drvSAMPL::show_rectangle(const float llx, const float lly, const float urx,
 }
 void drvSAMPL::show_image(const PSImage & imageinfo)
 {
-	if (outDirName == NIL || outBaseName == NIL) {
+	if (outBaseName == "") {
 		errf << "images cannot be handled via standard output. Use an output file" << endl;
 		return;
 	}
