@@ -7,7 +7,7 @@
 
    drvsample.cpp : Backend for TK
 
-   Copyright (C) 1993 - 2006 Wolfgang Glunz, wglunz34_AT_pstoedit.net
+   Copyright (C) 1993 - 2007 Wolfgang Glunz, wglunz34_AT_pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -34,6 +34,7 @@
 #include <math.h>
 
 
+#include "papersizes.h"
 
 
 static const char *colorstring(float r, float g, float b)
@@ -68,7 +69,7 @@ void drvTK::outputEscapedText(const char *str)
 
 
 drvTK::derivedConstructor(drvTK):
-constructBase, buffer(tempFile.asOutput()), objectId(1)
+constructBase, buffer(tempFile.asOutput()), objectId(1),paperinfo(0)
 {
 //  const RSString & l_pagesize = getPageSize();
 
@@ -76,166 +77,10 @@ constructBase, buffer(tempFile.asOutput()), objectId(1)
 	x_offset = 0.0;				/* set to fit to tk page      */
 	y_offset = 0.0;				/*          "                 */
 
-#if 0
-	// cannot write any header part, since we need the total number of pages
-	// in the header
-	for (unsigned int i = 0; i < d_argc; i++) {
-		assert(d_argv && d_argv[i]);
-		if (Verbose())
-			outf << "% " << d_argv[i] << endl;
-		if (!strcmp(d_argv[i], "-N")) {
-			tagNames = d_argv[i + 1];
-		} else if (!strcmp(d_argv[i], "-n")) {
-			tagNames = d_argv[i + 1];
-		} else if (!strcmp(d_argv[i], "-R")) {
-			swapHW = 1;
-		} else if (!strcmp(d_argv[i], "-I")) {
-			noImPress = 1;
-		}
-	}
-#endif
-
     const RSString pagesize = getPageSize();
-	if (!strcmp(pagesize.value(), "a0")) {
-		strcpy_s(pwidth,  ssize, "84.0c");
-		strcpy_s(pheight, ssize, "118.8c");
-	} else if (!strcmp(pagesize.value(), "a1")) {
-		strcpy_s(pwidth,  ssize, "59.4c");
-		strcpy_s(pheight, ssize, "84.0c");
-	} else if (!strcmp(pagesize.value(), "a2")) {
-		strcpy_s(pwidth,  ssize, "42.0c");
-		strcpy_s(pheight, ssize, "59.4c");
-	} else if (!strcmp(pagesize.value(), "a3")) {
-		strcpy_s(pwidth,  ssize, "29.7c");
-		strcpy_s(pheight, ssize, "42.0c");
-	} else if (!strcmp(pagesize.value(), "a4")) {
-		strcpy_s(pwidth,  ssize, "21.0c");
-		strcpy_s(pheight, ssize, "29.7c");
-	} else if (!strcmp(pagesize.value(), "a5")) {
-		strcpy_s(pwidth,  ssize, "14.8c");
-		strcpy_s(pheight, ssize, "21.0c");
-	} else if (!strcmp(pagesize.value(), "b4")) {
-		strcpy_s(pwidth,  ssize, "25.0c");
-		strcpy_s(pheight, ssize, "35.4c");
-	} else if (!strcmp(pagesize.value(), "b5")) {
-		strcpy_s(pwidth,  ssize, "18.2c");
-		strcpy_s(pheight, ssize, "25.7c");
-	} else if (!strcmp(pagesize.value(), "tabloid")) {
-		strcpy_s(pwidth,  ssize, "11.0i");
-		strcpy_s(pheight, ssize, "17.0i");
-	} else if (!strcmp(pagesize.value(), "ledger")) {
-		strcpy_s(pwidth,  ssize, "17.0i");
-		strcpy_s(pheight, ssize, "11.0i");
-	} else if (!strcmp(pagesize.value(), "legal")) {
-		strcpy_s(pwidth,  ssize, "8.5i");
-		strcpy_s(pheight, ssize, "14.0i");
-	} else if (!strcmp(pagesize.value(), "statement")) {
-		strcpy_s(pwidth,  ssize, "5.5i");
-		strcpy_s(pheight, ssize, "8.5i");
-	} else if (!strcmp(pagesize.value(), "executive")) {
-		strcpy_s(pwidth,  ssize, "7.25i");
-		strcpy_s(pheight, ssize, "10.5i");
-	} else if (!strcmp(pagesize.value(), "folio")) {
-		strcpy_s(pwidth,  ssize, "8.5i");
-		strcpy_s(pheight, ssize, "13.0i");
-	} else if (!strcmp(pagesize.value(), "quarto")) {
-		strcpy_s(pwidth,  ssize, "21.5c");
-		strcpy_s(pheight, ssize, "27.5c");
-	} else if (!strcmp(pagesize.value(), "10x14")) {
-		strcpy_s(pwidth,  ssize, "10.0i");
-		strcpy_s(pheight, ssize, "14.0i");
-	} else if (!strcmp(pagesize.value(), "note")) {
-		strcpy_s(pwidth,  ssize, "8.5i");
-		strcpy_s(pheight, ssize, "11.0i");
-	} else if (!strcmp(pagesize.value(), "env_9")) {
-		strcpy_s(pwidth,  ssize, "3.875i");
-		strcpy_s(pheight, ssize, "8.875i");
-	} else if (!strcmp(pagesize.value(), "env_10")) {
-		strcpy_s(pwidth,  ssize, "4.125i");
-		strcpy_s(pheight, ssize, "9.5i");
-	} else if (!strcmp(pagesize.value(), "env_11")) {
-		strcpy_s(pwidth,  ssize, "4.5i");
-		strcpy_s(pheight, ssize, "10.375i");
-	} else if (!strcmp(pagesize.value(), "env_14")) {
-		strcpy_s(pwidth,  ssize, "5.0i");
-		strcpy_s(pheight, ssize, "11.5i");
-	} else if (!strcmp(pagesize.value(), "env_dl")) {
-		strcpy_s(pwidth,  ssize, "11.0c");
-		strcpy_s(pheight, ssize, "22.0c");
-	} else if (!strcmp(pagesize.value(), "env_c3")) {
-		strcpy_s(pwidth,  ssize, "32.4c");
-		strcpy_s(pheight, ssize, "45.8c");
-	} else if (!strcmp(pagesize.value(), "env_c4")) {
-		strcpy_s(pwidth,  ssize, "22.9c");
-		strcpy_s(pheight, ssize, "32.4c");
-	} else if (!strcmp(pagesize.value(), "env_c5")) {
-		strcpy_s(pwidth,  ssize, "16.2c");
-		strcpy_s(pheight, ssize, "22.9c");
-	} else if (!strcmp(pagesize.value(), "env_c6")) {
-		strcpy_s(pwidth,  ssize, "11.4c");
-		strcpy_s(pheight, ssize, "16.2c");
-	} else if (!strcmp(pagesize.value(), "env_b4")) {
-		strcpy_s(pwidth,  ssize, "25.0c");
-		strcpy_s(pheight, ssize, "35.3c");
-	} else if (!strcmp(pagesize.value(), "env_b5")) {
-		strcpy_s(pwidth,  ssize, "17.6c");
-		strcpy_s(pheight, ssize, "25.0c");
-	} else if (!strcmp(pagesize.value(), "env_b6")) {
-		strcpy_s(pwidth,  ssize, "17.6c");
-		strcpy_s(pheight, ssize, "12.5c");
-	} else if (!strcmp(pagesize.value(), "env_italy")) {
-		strcpy_s(pwidth,  ssize, "11.0c");
-		strcpy_s(pheight, ssize, "23.0c");
-	} else if (!strcmp(pagesize.value(), "env_monarch")) {
-		strcpy_s(pwidth,  ssize, "3.875i");
-		strcpy_s(pheight, ssize, "7.5i");
-	} else if (!strcmp(pagesize.value(), "env_personal")) {
-		strcpy_s(pwidth,  ssize, "3.625i");
-		strcpy_s(pheight, ssize, "6.5i");
-	} else if (!strcmp(pagesize.value(), "fanfold_us")) {
-		strcpy_s(pwidth,  ssize, "14.875i");
-		strcpy_s(pheight, ssize, "11.0i");
-	} else if (!strcmp(pagesize.value(), "fanfold_std_german")) {
-		strcpy_s(pwidth,  ssize, "8.5i");
-		strcpy_s(pheight, ssize, "12.0i");
-	} else if (!strcmp(pagesize.value(), "fanfold_lgl_german")) {
-		strcpy_s(pwidth,  ssize, "8.5i");
-		strcpy_s(pheight, ssize, "13.0i");
-	} else if (!strcmp(pagesize.value(), "iso_b4")) {
-		strcpy_s(pwidth,  ssize, "25.0c");
-		strcpy_s(pheight, ssize, "35.3c");
-	} else if (!strcmp(pagesize.value(), "japanese_postcard")) {
-		strcpy_s(pwidth,  ssize, "10.0c");
-		strcpy_s(pheight, ssize, "14.8c");
-	} else if (!strcmp(pagesize.value(), "9x11")) {
-		strcpy_s(pwidth,  ssize, "9.0i");
-		strcpy_s(pheight, ssize, "11.0i");
-	} else if (!strcmp(pagesize.value(), "10x11")) {
-		strcpy_s(pwidth,  ssize, "10.0i");
-		strcpy_s(pheight, ssize, "11.0i");
-	} else if (!strcmp(pagesize.value(), "15x11")) {
-		strcpy_s(pwidth,  ssize, "15.0i");
-		strcpy_s(pheight, ssize, "11.0i");
-	} else if (!strcmp(pagesize.value(), "env_invite")) {
-		strcpy_s(pwidth,  ssize, "22.0c");
-		strcpy_s(pheight, ssize, "22.0c");
-	} else if (!strcmp(pagesize.value(), "a_plus")) {
-		strcpy_s(pwidth,  ssize, "22.7c");
-		strcpy_s(pheight, ssize, "35.6c");
-	} else if (!strcmp(pagesize.value(), "b_plus")) {
-		strcpy_s(pwidth,  ssize, "30.5c");
-		strcpy_s(pheight, ssize, "48.7c");
-	} else {
-		// default
-		strcpy_s(pwidth,  ssize, "8.5i");
-		strcpy_s(pheight, ssize, "11.0i");
-	}
-	if (options->swapHW) {
-		char psave[ssize];
-		strcpy_s(psave,ssize, pwidth);
-		strcpy_s(pwidth, ssize,pheight);
-		strcpy_s(pheight, ssize,psave);
-	}
+	paperinfo = getPaperInfo(pagesize.value());
+	// cout << "Paper Info for " << pagesize << " is " << (void*) paperinfo << endl;
+	if (!paperinfo) { paperinfo = getPaperInfo("Letter"); } //default 
 
 	canvasCreate();
 }
@@ -1119,9 +964,22 @@ void drvTK::open_page()
 {
 	if (!options->noImPress) {
 		buffer <<
-			"	set Global(CurrentPageId) [expr $Global(CurrentPageId) + 1]"
-			<< endl << "	set Global(PageHeight) " << pheight << endl <<
-			"	set Global(PageWidth) " << pwidth << endl <<
+			"	set Global(CurrentPageId) [expr $Global(CurrentPageId) + 1]" << endl;
+		const char * const unit = paperinfo->preferredunit == p_mm ? "c" : "i";
+		const double unitfactor = paperinfo->preferredunit == p_mm ? 0.1f : 1.0f; // need to write in cm not in mm
+		const double pwidth = paperinfo->preferredunit == p_mm ? paperinfo->mmw*unitfactor : paperinfo->inw;
+		const double pheight = paperinfo->preferredunit == p_mm ? paperinfo->mmh*unitfactor : paperinfo->inh;
+
+		if (options->swapHW) { 
+			buffer << 
+			"	set Global(PageHeight) " << pwidth  << unit << endl <<
+			"	set Global(PageWidth) "  << pheight << unit << endl ;
+		} else {
+			buffer << 
+			"	set Global(PageHeight) " << pheight << unit << endl <<
+			"	set Global(PageWidth) "  << pwidth  << unit << endl ;
+		}
+		buffer << 
 			"	set Global(Landscape) 0" << endl <<
 			"	newCanvas .can c$Global(CurrentPageId)" << endl;
 	}
@@ -1134,12 +992,10 @@ void drvTK::show_text(const TextInfo & textinfo)
 	int boldfont = (strstr(textinfo.currentFontName.value(), "Bold") != NIL);
 	int italicfont = ((strstr(textinfo.currentFontName.value(), "Italic") != NIL)
 					  || (strstr(textinfo.currentFontName.value(), "Oblique") != NIL));
-	char tempfontname[1024];
+	char*  tempfontname = cppstrdup(textinfo.currentFontName.value()) ; // char tempfontname[1024];
 	char fonttype = 'r';
 	char *i;
 	int actualFontSize;
-
-	strcpy_s(tempfontname, 1024, textinfo.currentFontName.value());
 	i = strchr(tempfontname, '-');
 	if (i != NIL) {
 		*i = '\0';
@@ -1177,6 +1033,7 @@ void drvTK::show_text(const TextInfo & textinfo)
 	if (strcmp(options->tagNames.value.value(), "") && !(options->noImPress)) {
 		buffer << "set Group($Global(CurrentCanvas),$i) \"" << options->tagNames << "\"" << endl;
 	}
+	delete [] tempfontname;
 }
 
 static const int Fill = 1;
